@@ -1,6 +1,6 @@
 from contextlib import contextmanager
 from copy import copy
-from itertools import product, izip, imap
+from itertools import product, izip, imap, chain
 from collections import namedtuple
 from json import dumps
 
@@ -107,6 +107,32 @@ class Space:
         keys = (cls.key(point, False),)
         return cls._db.fetch(keys).next()
 
+    @classmethod
+    def dice(cls, point):
+        points = list(cls.drill(point))
+        for point, res in izip(points, cls.fetchmany(points)):
+            point.update(res)
+            yield point
+
+    @classmethod
+    def drill(cls, point):
+        res = {}
+        vals = []
+        for name, dim in cls._dimensions:
+            if name not in point:
+                continue
+            vals.append(dim.explode(point[name]))
+
+        for point_tuple in product(*vals):
+            sub_point = {}
+            pos = 0
+            for name, dim in cls._dimensions:
+                if name not in point:
+                    continue
+                sub_point[name] = point_tuple[pos]
+                pos += 1
+            yield sub_point
+
 
 def build_space(data_point, name):
     """
